@@ -28,6 +28,7 @@ urlpatterns = patterns('',
     url(r'', include('rooms.urls', namespace='rooms')),
     url(r'', include('events.urls', namespace='events')),
     url(r'', include('managers.urls', namespace='managers')),
+    url(r'', include('farnswiki.urls')),
 )
 
 urlpatterns += patterns('base.views',
@@ -36,6 +37,7 @@ urlpatterns += patterns('base.views',
     url(r'^landing/$', 'landing_view', name='external'),
     url(r'^help/$', 'help_view', name='helppage'),
     url(r'^login/$', 'login_view', name='login'),
+    url(r'^login/$', 'login_view', name='account_login'),
     url(r'^logout/$', 'logout_view', name='logout'),
     url(r'^site_map/$', 'site_map_view', name='site_map'),
     url(r'^member_directory/$', 'member_directory_view', name='member_directory'),
@@ -53,4 +55,5 @@ urlpatterns += patterns('base.views',
         'reset_pw_confirm_view', name='reset_pw_confirm'),
     url(r'^recount/$', "recount_view", name="recount"),
     url(r'^archives/$', 'archives_view', name='archives'),
+    url(r'^get_updates/$', 'get_updates_view', name='get_updates'),
 )
