@@ -5,18 +5,19 @@ Author: Karandeep Singh Nagra
 '''
 
 from django.contrib import admin
-from base.models import ProfileRequest
 from managers.models import Manager, RequestType, Request, Response, Announcement
 
 class ManagerAdmin(admin.ModelAdmin):
     list_display = ('title', 'incumbent', 'email')
     search_fields = ('title', 'incumbent', 'email', 'duties')
     list_filter = ('email',)
+admin.site.register(Manager, ManagerAdmin)
 
 class RequestTypeAdmin(admin.ModelAdmin):
     list_display = ('name', 'enabled')
     search_fields = ('name', 'managers')
     list_filter = ('name', 'managers')
+admin.site.register(RequestType, RequestTypeAdmin)
 
 class RequestAdmin(admin.ModelAdmin):
     list_display = ('owner', 'post_date', 'status')
@@ -24,7 +25,8 @@ class RequestAdmin(admin.ModelAdmin):
     list_filter = ('status',)
     date_hierarchy = 'post_date'
     ordering = ('-post_date',)
-    readonly_fields = ('post_date',)
+    readonly_fields = ('post_date', 'change_date')
+admin.site.register(Request, RequestAdmin)
 
 class ResponseAdmin(admin.ModelAdmin):
     list_display = ('owner', 'post_date', 'request', 'action')
@@ -33,14 +35,7 @@ class ResponseAdmin(admin.ModelAdmin):
     date_hierarchy = 'post_date'
     ordering = ('-post_date',)
     readonly_fields = ('post_date',)
-
-class ProfileRequestAdmin(admin.ModelAdmin):
-    list_display = ('username', 'last_name', 'first_name', 'email')
-    search_fields = ('username', 'last_name', 'first_name', 'email')
-    date_hierarchy = 'request_date'
-    list_filter = ('request_date',)
-    ordering = ('request_date',)
-    readonly_fields = ('username', 'last_name', 'first_name', 'email')
+admin.site.register(Response, ResponseAdmin)
 
 class AnnouncementAdmin(admin.ModelAdmin):
     list_display = ('manager', 'incumbent', 'post_date', 'pinned')
@@ -49,10 +44,4 @@ class AnnouncementAdmin(admin.ModelAdmin):
     list_filter = ('pinned',)
     ordering = ('-post_date', 'pinned')
     readonly_fields = ('manager', 'incumbent', 'post_date', 'body')
-
-admin.site.register(Manager, ManagerAdmin)
-admin.site.register(RequestType, RequestTypeAdmin)
-admin.site.register(Request, RequestAdmin)
-admin.site.register(Response, ResponseAdmin)
-admin.site.register(ProfileRequest, ProfileRequestAdmin)
 admin.site.register(Announcement, AnnouncementAdmin)
