@@ -6,24 +6,28 @@ Author: Karandeep Singh Nagra
 
 from datetime import timedelta
 
+import json
+
 from django.conf import settings
 from django.contrib import messages
 from django.contrib.auth import logout, login
 from django.contrib.auth.models import User
 from django.core.urlresolvers import reverse
 from django.db.models import Q
-from django.http import HttpResponseRedirect
+from django.http import HttpResponseRedirect, HttpResponse, Http404
 from django.shortcuts import render_to_response, get_object_or_404
 from django.template import RequestContext
 from django.utils.timezone import now
 
 from utils.variables import ANONYMOUS_USERNAME, MESSAGES
-from base.decorators import admin_required, profile_required, president_admin_required
+from base.decorators import admin_required, profile_required, \
+    president_admin_required, ajax_capable
 from base.models import UserProfile
 from base.redirects import red_home
 from managers.models import Manager, RequestType, Request, Response, Announcement
 from managers.forms import ManagerForm, RequestTypeForm, RequestForm, ResponseForm, \
-     ManagerResponseForm, VoteForm, AnnouncementForm, PinForm
+    ManagerResponseForm, VoteForm, AnnouncementForm, PinForm
+from managers.ajax import build_ajax_votes
 from threads.models import Thread, Message
 
 @admin_required
@@ -103,6 +107,7 @@ def add_manager_view(request):
         return HttpResponseRedirect(reverse('managers:add_manager'))
     return render_to_response('edit_manager.html', {
         'page_name': "Admin - Add Manager",
+        'managerset': Manager.objects.all(),
         'form': form,
         }, context_instance=RequestContext(request))
 
@@ -156,7 +161,6 @@ def add_request_type_view(request):
         'form': form,
         }, context_instance=RequestContext(request))
 
-
 @president_admin_required
 def edit_request_type_view(request, typeName):
     ''' View to edit a new request type.  Restricted to presidents and superadmins.
@@ -252,7 +256,7 @@ def requests_view(request, requestType):
             break
     return render_to_response('requests.html', {
         'manager': manager,
-        'request_type': request_type.name.title(),
+        'request_type': request_type,
         'page_name': page_name,
         'request_form': request_form,
         'requests_dict': requests_dict,
@@ -264,7 +268,7 @@ def my_requests_view(request):
     '''
     Show user his/her requests, sorted by request_type.
     '''
-    page_name = "My Requests"
+    page_name = "Your Requests"
     userProfile = UserProfile.objects.get(user=request.user)
     my_requests = Request.objects.filter(owner=userProfile)
     # A pseudo dictionary, actually a list with items of form
@@ -288,12 +292,14 @@ def my_requests_view(request):
                     initial={'action': Response.NONE},
                     profile=userProfile,
                     request=req,
+                    prefix="response-{0}".format(req.pk),
                     )
             else:
                 response_form = ResponseForm(
                     request.POST if "add_response-{0}".format(req.pk) in request.POST else None,
                     profile=userProfile,
                     request=req,
+                    prefix="response-{0}".format(req.pk),
                     )
 
             upvote = userProfile in req.upvotes.all()
@@ -302,6 +308,7 @@ def my_requests_view(request):
                 request.POST or None,
                 profile=userProfile,
                 request=req,
+                prefix="vote-{0}",
                 )
 
             if response_form.is_valid():
@@ -316,6 +323,7 @@ def my_requests_view(request):
             request.POST if "submit_request" in request.POST else None,
             profile=userProfile,
             request_type=request_type,
+            prefix="request-{0}".format(request_type.pk),
             )
         if request_form.is_valid():
             request_form.save()
@@ -335,7 +343,7 @@ def list_my_requests_view(request):
     userProfile = UserProfile.objects.get(user=request.user)
     requests = Request.objects.filter(owner=userProfile)
     return render_to_response('list_requests.html', {
-        'page_name': "My Requests",
+        'page_name': "Your Requests",
         'requests': requests,
         }, context_instance=RequestContext(request))
 
@@ -409,10 +417,55 @@ def list_all_requests_view(request, requestType):
         }, context_instance=RequestContext(request))
 
 @profile_required
+@ajax_capable
 def request_view(request, request_pk):
     '''
     The view of a single request.
     '''
+    print "NOT AJAX REQUEST"
+    if request.is_ajax():
+        print "AJAX REQUEST"
+        if not request.user.is_authenticated():
+            return HttpResponse(json.dumps(dict()),
+                                content_type="application/json")
+
+        try:
+            relevant_request = Request.objects.get(pk=request_pk)
+        except Request.DoesNotExist:
+            return HttpResponse(json.dumps(dict()),
+                                content_type="application/json")
+
+        try:
+            user_profile = UserProfile.objects.get(user=request.user)
+        except UserProfile.DoesNotExist:
+            return HttpResponse(json.dumps(dict()),
+                                content_type="application/json")
+
+        upvote = user_profile in relevant_request.upvotes.all()
+        vote_form = VoteForm(
+            request.POST if "upvote" in request.POST else None,
+            profile=user_profile,
+            request=relevant_request,
+            )
+        if vote_form.is_valid():
+            vote_form.save()
+            response = dict()
+            response['vote_count_{pk}'.format(pk=request_pk)] = \
+                relevant_request.upvotes.all().count()
+
+            list_string = 'vote_list_{pk}'.format(pk=request_pk)
+            vote_string = 'in_votes_{pk}'.format(pk=request_pk)
+            count_string = 'vote_count_{pk}'.format(pk=request_pk)
+            response[list_string], response[vote_string], \
+                response[count_string] = build_ajax_votes(
+                    relevant_request,
+                    user_profile
+                )
+            return HttpResponse(json.dumps(response),
+                                content_type="application/json")
+        return HttpResponse(json.dumps(dict()),
+                            content_type="application/json")
+
     relevant_request = get_object_or_404(Request, pk=request_pk)
 
     if relevant_request.private:
@@ -442,8 +495,8 @@ def request_view(request, request_pk):
             )
     upvote = userProfile in relevant_request.upvotes.all()
     vote_form = VoteForm(
-        request.POST if "vote" in request.POST else None,
-        profile=UserProfile,
+        request.POST if "upvote" in request.POST else None,
+        profile=userProfile,
         request=relevant_request,
         )
     if response_form.is_valid():
@@ -452,7 +505,7 @@ def request_view(request, request_pk):
             'request_pk': relevant_request.pk,
             }))
     if vote_form.is_valid():
-        vote_form.save(pk=request_pk)
+        vote_form.save()
         return HttpResponseRedirect(reverse('managers:view_request', kwargs={
             'request_pk': relevant_request.pk,
             }))
@@ -505,9 +558,10 @@ def edit_announcement_view(request, announcement_pk):
         request.POST or None,
         instance=announce,
         profile=profile,
+        editing=True,
         )
     if announcement_form.is_valid():
-        announcement_form.save()
+        announcement_form.save(request)
         return HttpResponseRedirect(
             reverse('managers:view_announcement', kwargs={"announcement_pk": announcement_pk}),
             )
@@ -526,11 +580,11 @@ def announcements_view(request):
     manager_positions = Manager.objects.filter(incumbent=userProfile)
     if manager_positions:
         announcement_form = AnnouncementForm(
-            request.POST if "post_announcement"in request.POST else None,
+            request.POST if "post_announcement" in request.POST else None,
             profile=userProfile,
             )
     if announcement_form and announcement_form.is_valid():
-        announcement_form.save()
+        announcement_form.save(request)
         return HttpResponseRedirect(reverse('managers:announcements'))
 
     # A pseudo-dictionary, actually a list with items of form:
